@@ -7,7 +7,7 @@ use Data::Dumper;
 use Exporter qw(import);
 use HTTP::Tiny;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our @EXPORT = qw(myip myip6);
 
@@ -34,7 +34,7 @@ sub _get {
     my $status = $response->{status};
 
     if ($status != 200) {
-        warn "Failed to connect to $url to get your address";
+        warn "Failed to connect to $url to get your address: $response->{content}";
         return '';
     }
 
